@@ -83,6 +83,7 @@ class DuckDB(Dialect):
             ":=": TokenType.EQ,
             "ATTACH": TokenType.COMMAND,
             "CHARACTER VARYING": TokenType.VARCHAR,
+            "EXCLUDE": TokenType.EXCEPT,
         }
 
     class Parser(parser.Parser):
@@ -173,3 +174,8 @@ class DuckDB(Dialect):
             exp.DataType.Type.VARCHAR: "TEXT",
             exp.DataType.Type.NVARCHAR: "TEXT",
         }
+
+        STAR_MAPPING = {
+            **generator.Generator.STAR_MAPPING,
+            "except": "EXCLUDE",
+        }
