@@ -550,14 +550,17 @@ class Generator:
                 else:
                     expression_sql = f" AS{expression_sql}"
 
-        replace = " OR REPLACE" if expression.args.get("replace") else ""
-        unique = " UNIQUE" if expression.args.get("unique") else ""
-        exists_sql = " IF NOT EXISTS" if expression.args.get("exists") else ""
+        postindex_props_sql = ""
+        if properties_locs.get(exp.Properties.Location.POST_INDEX):
+            postindex_props_sql = self.properties(
+                exp.Properties(expressions=properties_locs[exp.Properties.Location.POST_INDEX]),
+                wrapped=False,
+                prefix=" ",
+            )
 
         indexes = expression.args.get("indexes")
-        index_sql = ""
         if indexes:
-            indexes_sql = []
+            indexes_sql: t.List[str] = []
             for index in indexes:
                 ind_unique = " UNIQUE" if index.args.get("unique") else ""
                 ind_primary = " PRIMARY" if index.args.get("primary") else ""
@@ -568,21 +571,24 @@ class Generator:
                     if index.args.get("columns")
                     else ""
                 )
-                if index.args.get("primary") and properties_locs.get(
-                    exp.Properties.Location.POST_INDEX
-                ):
-                    postindex_props_sql = self.properties(
-                        exp.Properties(
-                            expressions=properties_locs[exp.Properties.Location.POST_INDEX]
-                        ),
-                        wrapped=False,
+                ind_sql = f"{ind_unique}{ind_primary}{ind_amp} INDEX{ind_name}{ind_columns}"
+
+                if indexes_sql:
+                    indexes_sql.append(ind_sql)
+                else:
+                    indexes_sql.append(
+                        f"{ind_sql}{postindex_props_sql}"
+                        if index.args.get("primary")
+                        else f"{postindex_props_sql}{ind_sql}"
                     )
-                    ind_columns = f"{ind_columns} {postindex_props_sql}"
 
-                indexes_sql.append(
-                    f"{ind_unique}{ind_primary}{ind_amp} INDEX{ind_name}{ind_columns}"
-                )
             index_sql = "".join(indexes_sql)
+        else:
+            index_sql = postindex_props_sql
+
+        replace = " OR REPLACE" if expression.args.get("replace") else ""
+        unique = " UNIQUE" if expression.args.get("unique") else ""
+        volatile = " VOLATILE" if expression.args.get("volatile") else ""
 
         postcreate_props_sql = ""
         if properties_locs.get(exp.Properties.Location.POST_CREATE):
@@ -593,7 +599,7 @@ class Generator:
                 wrapped=False,
             )
 
-        modifiers = "".join((replace, unique, postcreate_props_sql))
+        modifiers = "".join((replace, unique, volatile, postcreate_props_sql))
 
         postexpression_props_sql = ""
         if properties_locs.get(exp.Properties.Location.POST_EXPRESSION):
@@ -606,6 +612,7 @@ class Generator:
                 wrapped=False,
             )
 
+        exists_sql = " IF NOT EXISTS" if expression.args.get("exists") else ""
         no_schema_binding = (
             " WITH NO SCHEMA BINDING" if expression.args.get("no_schema_binding") else ""
         )
@@ -1335,14 +1342,15 @@ class Generator:
     def placeholder_sql(self, expression: exp.Placeholder) -> str:
         return f":{expression.name}" if expression.name else "?"
 
-    def subquery_sql(self, expression: exp.Subquery) -> str:
+    def subquery_sql(self, expression: exp.Subquery, sep: str = " AS ") -> str:
         alias = self.sql(expression, "alias")
+        alias = f"{sep}{alias}" if alias else ""
 
         sql = self.query_modifiers(
             expression,
             self.wrap(expression),
             self.expressions(expression, key="pivots", sep=" "),
-            f" AS {alias}" if alias else "",
+            alias,
         )
 
         return self.prepend_ctes(expression, sql)
@@ -1741,6 +1749,9 @@ class Generator:
     def div_sql(self, expression: exp.Div) -> str:
         return self.binary(expression, "/")
 
+    def overlaps_sql(self, expression: exp.Overlaps) -> str:
+        return self.binary(expression, "OVERLAPS")
+
     def distance_sql(self, expression: exp.Distance) -> str:
         return self.binary(expression, "<->")
 
