@@ -60,6 +60,7 @@ class TokenType(AutoName):
     STRING = auto()
     NUMBER = auto()
     IDENTIFIER = auto()
+    DATABASE = auto()
     COLUMN = auto()
     COLUMN_DEF = auto()
     SCHEMA = auto()
@@ -203,6 +204,7 @@ class TokenType(AutoName):
     IS = auto()
     ISNULL = auto()
     JOIN = auto()
+    JOIN_MARKER = auto()
     LANGUAGE = auto()
     LATERAL = auto()
     LAZY = auto()
@@ -235,6 +237,7 @@ class TokenType(AutoName):
     OUTER = auto()
     OUT_OF = auto()
     OVER = auto()
+    OVERLAPS = auto()
     OVERWRITE = auto()
     PARTITION = auto()
     PARTITION_BY = auto()
@@ -491,6 +494,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "CURRENT_DATE": TokenType.CURRENT_DATE,
         "CURRENT ROW": TokenType.CURRENT_ROW,
         "CURRENT_TIMESTAMP": TokenType.CURRENT_TIMESTAMP,
+        "DATABASE": TokenType.DATABASE,
         "DEFAULT": TokenType.DEFAULT,
         "DELETE": TokenType.DELETE,
         "DESC": TokenType.DESC,
@@ -564,6 +568,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "OUTER": TokenType.OUTER,
         "OUT OF": TokenType.OUT_OF,
         "OVER": TokenType.OVER,
+        "OVERLAPS": TokenType.OVERLAPS,
         "OVERWRITE": TokenType.OVERWRITE,
         "PARTITION": TokenType.PARTITION,
         "PARTITION BY": TokenType.PARTITION_BY,
@@ -652,6 +657,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "DOUBLE PRECISION": TokenType.DOUBLE,
         "JSON": TokenType.JSON,
         "CHAR": TokenType.CHAR,
+        "CHARACTER": TokenType.CHAR,
         "NCHAR": TokenType.NCHAR,
         "VARCHAR": TokenType.VARCHAR,
         "VARCHAR2": TokenType.VARCHAR,
@@ -687,6 +693,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "ALTER VIEW": TokenType.COMMAND,
         "ANALYZE": TokenType.COMMAND,
         "CALL": TokenType.COMMAND,
+        "COMMENT ON": TokenType.COMMAND,
         "COPY": TokenType.COMMAND,
         "EXPLAIN": TokenType.COMMAND,
         "OPTIMIZE": TokenType.COMMAND,
